local toc, data = ...
local AddonId = toc.identifier
--MAXHP/MP was line 119
-- Local config options ---------------------------------------------------------
local BlackRaidFrameWidth = 130
local BlackRaidFrameTopBarHeight = 36
local BlackRaidFrameBottomBarHeight = 12
local BlackRaidFrameMargin = 2
local BlackRaidFrameHeight = BlackRaidFrameTopBarHeight + BlackRaidFrameBottomBarHeight 
---------------------------------------------------------------------------------

-- Frame Configuration Options --------------------------------------------------
local BlackRaidFrame = WT.UnitFrame:Template("BlackRaidFrame")
BlackRaidFrame.Configuration.Name = "Black Raid Frame"
BlackRaidFrame.Configuration.RaidSuitable = true
BlackRaidFrame.Configuration.FrameType = "Frame"
BlackRaidFrame.Configuration.Width = BlackRaidFrameWidth + 3
BlackRaidFrame.Configuration.Height = BlackRaidFrameHeight + 3
BlackRaidFrame.Configuration.Resizable = { BlackRaidFrameWidth + 3, BlackRaidFrameHeight + 3, 300, 100 }
---------------------------------------------------------------------------------

-- Override the buff filter to hide some buffs ----------------------------------
local buffPriorities = 
{
	["Track Wood"] = 0,
	["Track Ore"] = 0,
	["Track Plants"] = 0,
	["Rested"] = 0,
	["Prismatic Glory"] = 0,
	["Looking for Group Cooldown"] = 0,
}
function BlackRaidFrame:GetBuffPriority(buff)
	if not buff then return 2 end
	return buffPriorities[buff.name] or 2
end
---------------------------------------------------------------------------------

function BlackRaidFrame:Construct(options)

	local template =
	{
		elements = 
		{
			{
				-- Generic Element Configuration
				id="frameBackdrop", type="Frame", parent="frame", layer=0,
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" } 
				},
				visibilityBinding="id",
				-- Type Specific Element Configuration  was alpha.5
				texAddon = AddonId, texFile = "img/wtMiniFrame_bg.png", alpha=.5,
				color={r=0,g=0,b=0,a=.5}, colorBinding="aggroColor",
			}, 
			{
				-- Generic Element Configuration
				id="frameBlocked", type="Frame", parent="frameBackdrop", layer=15, visibilityBinding="blockedOrRanged",
				color={r=0,g=0,b=0},alpha=0.2,
				attach = 
				{ 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=3, offsetY=3 },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT", offsetX=-3, offsetY=-3 } 
				},
			}, 
			{
				-- Generic Element Configuration
				id="barResource", type="Bar", parent="frameBackdrop", layer=10,
				attach = {
					{ point="BOTTOMLEFT", element="frame", targetPoint="BOTTOMLEFT", offsetX=3, offsetY=-3 },
					{ point="RIGHT", element="frame", targetPoint="RIGHT", offsetX=-3 },
				},
				-- visibilityBinding="id",
				-- Type Specific Element Configuration
				binding="resourcePercent", height=BlackRaidFrameBottomBarHeight, color={r=0,g=0,b=0,a=1},
				texAddon=AddonId, texFile="img/Black.png",
				backgroundColor={r=5, g=0, b=0, a=.3}
			},
			{
				-- Generic Element Configuration
				id="barHealth", type="Bar", parent="frameBackdrop", layer=10,
				attach = {
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=3, offsetY=3 },
					{ point="BOTTOMRIGHT", element="barResource", targetPoint="TOPRIGHT" },
				},
				-- visibilityBinding="id",
				growthDirection="right",
				-- Type Specific Element Configuration
				binding="healthPercent", height=raidFrameTopBarHeight, color={r=0,g=0,b=0,a=5},
				texAddon=AddonId, texFile="img/bb.png", 
				backgroundColor={r=5, g=0, b=0, a=.3}
			},
			{
				-- Generic Element Configuration color was black alpha of.3
				id="frameColor", type="Frame", parent="frameBackdrop", layer=15, alpha=0.5,
				attach = { 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=3, offsetY=3 },
					{ point="BOTTOMRIGHT", element="barResource", targetPoint="TOPRIGHT" }
				},
				color={r=0,g=0,b=0,a=.3}, 
			},
			{
				-- Generic Element Configuration same as above
				id="frameColor2", type="Frame", parent="frameBackdrop", layer=15, alpha=0.5,
				attach = { 
					{ point="TOPLEFT", element="barHealth", targetPoint="BOTTOMLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT", offsetX=-3, offsetY=-3 }
				},
				color={r=0,g=0,b=0,a=.3}, 
			},
			{
				-- Generic Element Configuration
				id="labelHealth", type="Label", parent="frame", layer=20, alpha=1,
				attach = {{ point="TOPRIGHT", element="barHealth", targetPoint="TOPRIGHT", offsetX=1, offsetY=-1 }},
				visibilityBinding="health",
				-- Type Specific Element Configuration
				text="{healthPercent}%", default="", colorBinding="callingColor", fontSize=12
			},
			{
				id="imgRole", type="ImageSet", parent="frameBackdrop", layer=20,
				attach = {{ point="TOPLEFT", element="barHealth", targetPoint="TOPLEFT", offsetX=2, offsetY=2.5 }},
				-- Type Specific Element Configuration
				texAddon=AddonId, texFile="img/Roles1.png", nameBinding="role", cols=1, rows=5, 
				names = { ["tank"] = 0, ["heal"] = 1, ["dps"] = 2, ["support"] = 3 }, defaultIndex = "hide"
			},
			{
				-- Generic Element Configuration
				id="labelName", type="Label", parent="frame", layer=20, alpha=1,
				attach = {{ point="TOPLEFT", element="imgRole", targetPoint="TOPRIGHT", offsetX=0, offsetY=-5 }},
				visibilityBinding="name",
				-- Type Specific Element Configuration
				text="{nameMini}", default="", colorBinding="callingColor", fontSize=14,
			},
			{
				-- Generic Element Configuration was colorBinding=resourceColor was centerright
				id="labelresourceR", type="Label", parent="frame", layer=20, alpha=1,
				attach = {{ point="CENTERLEFT", element="barResource", targetPoint="CENTERLEFT" }},
				visibilityBinding="resource",
				-- Type Specific Element Configuration
				text="{resourcePercent}%", default="", colorBinding="callingColor", fontSize=9
			},
			{
				-- Generic Element Configuration
				id="labelMark", type="Label", parent="frameBackdrop", layer=20,
				attach = {{ point="CENTERLEFT", element="frame", targetPoint="CENTERLEFT", offsetX=2, offsetY=2 }},
				visibilityBinding="mark",alpha=1,
				-- Type Specific Element Configuration
				text="{mark}", default="X", fontSize=20
			},
			{
				-- Generic Element Configuration
				id="imgReady", type="ImageSet", parent="frame", layer=60,
				attach = {{ point="CENTER", element="frame", targetPoint="CENTER" }},
				-- Type Specific Element Configuration
				texAddon=AddonId, texFile="img/wtReady.png", nameBinding="readyStatus", cols=1, rows=2, 
				names = { ["ready"] = 0, ["notready"] = 1 }, defaultIndex = "hide",
			},			
			{
			    --added status remove if needed
				id="labelStatus", type="Label", parent="frameBackdrop", layer=20,
				attach = {{ point="BOTTOMCENTER", element="frameBackdrop", targetPoint="BOTTOMCENTER", offsetX=0, offsetY=-4 }},
				visibilityBinding="name",
				-- Type Specific Element Configuration
				text=" {raidStatus}", default="", fontSize=12
			},
			{
				--DeBuff Icons iconSize was 20
				id="buffPanelDebuffs", type="BuffPanel", parent="frame", layer=90,
				attach = {{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT", offsetX=-1, offsetY=-1 }},
				rows=1, cols=5, iconSize=22, iconSpacingHorizontal=1, iconSpacingVertical=1, borderThickness=0.5, 
				acceptLowPriorityBuffs=false, acceptMediumPriorityBuffs=false, acceptHighPriorityBuffs=false, acceptCriticalPriorityBuffs=false,
				acceptLowPriorityDebuffs=true, acceptMediumPriorityDebuffs=true, acceptHighPriorityDebuffs=true, acceptCriticalPriorityDebuffs=true,
				growthDirection = "left_up", borderColor={r=0,g=0,b=0,a=1},
				sweepOverlay=false,
			},
			
		}
	}
	
	for idx,element in ipairs(template.elements) do
		if options.excludeBuffs and element.type=="BuffPanel" then
			-- Don't add buff panels if excluding them
		else
			self:CreateElement(element)
		end 
	end
	
	self:SetSecureMode("restricted")
	self:SetMouseoverUnit(self.UnitSpec)
	self.Event.LeftClick = "target @" .. self.UnitSpec
	self.Event.RightClick = function() if self.UnitId then Command.Unit.Menu(self.UnitId) end end
end

--added vitual property of status text remove if causing error
WT.Unit.CreateVirtualProperty("raidStatus", { "offline", "afk", "dead" },
	function(unit)
		if unit.offline then
			return "OFFLINE"
		elseif unit.afk then
			return "AWAY"
		elseif unit.dead then
			return "DEATH"
		else
			return nil
		end
	end)
--"nameMini" from Noshei
WT.Unit.CreateVirtualProperty("nameMini", { "name" },
	function(unit)
		if unit.name and unit.name:len() > 11 then
			nameMini = unit.name:sub(1, 8) .. "..."
			return nameMini
		else
			return unit.name
		end
	end)	