local toc, data = ...
local AddonId = toc.identifier

-- Local config options ---------------------------------------------------------
local NervaRaidFrameWidth = 90
local NervaRaidFrameTopBarHeight = 21
local NervaRaidFrameBottomBarHeight = 6
local NervaRaidFrameMargin = 2
local NervaRaidFrameHeight = NervaRaidFrameTopBarHeight + NervaRaidFrameBottomBarHeight
local NervaRaidFrameFadeRange = 35
local NervaRaidFrameFadeRangeSqu = NervaRaidFrameFadeRange * NervaRaidFrameFadeRange
---------------------------------------------------------------------------------

-- Frame Configuration Options --------------------------------------------------
local NervaRaidFrame = WT.UnitFrame:Template("NervaRaidFrame")
NervaRaidFrame.Configuration.Name = "Nervas Raid Frame"
NervaRaidFrame.Configuration.RaidSuitable = true
NervaRaidFrame.Configuration.FrameType = "Frame"
NervaRaidFrame.Configuration.Width = NervaRaidFrameWidth
NervaRaidFrame.Configuration.Height = NervaRaidFrameHeight + 3
NervaRaidFrame.Configuration.Resizable = { NervaRaidFrameWidth, NervaRaidFrameHeight + 3, 300, 100 }
---------------------------------------------------------------------------------

-- Override the buff filter to hide some buffs ----------------------------------
local buffPriorities = 
{
	["Track Wood"] = 0,
	["Track Ore"] = 0,
	["Track Plants"] = 0,
	["Rested"] = 0,
	["Prismatic Glory"] = 0,
	["Looking for Group Cooldown"] = 0,
}
function NervaRaidFrame:GetBuffPriority(buff)
	if not buff then return 2 end
	return buffPriorities[buff.name] or 2
end
---------------------------------------------------------------------------------

function NervaRaidFrame:Construct(options)

	local template =
	{
		elements = 
		{
			{
				-- Generic Element Configuration
				id="frameBackdrop", type="Frame", parent="frame", layer=0,
				attach = { 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" }
				},
				visibilityBinding="id",
				-- Type Specific Element Configuration alpha was .5 and a=.3 colorBinding aggroColor
				texAddon = AddonId, texFile = "img/Flat.png", alpha=0.5,
				color={r=0,g=0,b=0,a=0.3},
			},
			{
				-- Generic Element Configuration
				id="frameBlocked", type="Frame", parent="frameBackdrop", layer=20, visibilityBinding="blockedOrRanged",
				color={r=0,g=0,b=0},alpha=0.8,
				attach = { 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT" },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" }
				},
			}, 
			{
				-- Generic Element Configuration
				id="barResource", type="Bar", parent="frameBackdrop", layer=10,
				attach = {
					{ point="BOTTOMLEFT", element="frame", targetPoint="BOTTOMLEFT", offsetX=1, offsetY=0 },
					{ point="RIGHT", element="frame", targetPoint="RIGHT", offsetX=-1 }
				},
				-- Type Specific Element Configuration was a=1
				binding="resourcePercent", height=NervaRaidFrameBottomBarHeight, colorBinding="resourceColor",
				texAddon=AddonId, texFile="img/Grey.png",
				backgroundColor={r=0, g=0, b=0, a=1}
			},
			{
				-- Generic Element Configuration
				id="barHealth", type="Bar", parent="frameBackdrop", layer=10,
				attach = {
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=1, offsetY=3 },
					{ point="BOTTOMRIGHT", element="barResource", targetPoint="TOPRIGHT" }
				},
				growthDirection="right",
				-- Type Specific Element Configuration was a=0
				binding="healthPercent", height=NervaRaidFrameTopBarHeight, colorBinding="callingColor",
				texAddon=AddonId, texFile="img/Grey.png",
				backgroundColor={r=0, g=0, b=0, a=0}
			},
			{
				-- Generic Element Configuration aggro bar was a=1
				id="frameAggro", type="Frame", parent="frameBackdrop", layer=10,
				attach = { 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=1, offsetY=0 },
					{ point="BOTTOMRIGHT", element="barHealth", targetPoint="TOPRIGHT" }
				},
				color={r=0,g=0,b=0,a=1}, colorBinding="aggroColor",
			},
			{
				-- Generic Element Configuration MP Background was callingColor alpha .3
				id="frameColor", type="Frame", parent="frameBackdrop", layer=15, alpha=0.6,
				attach = { 
					{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=1, offsetY=3 },
					{ point="BOTTOMRIGHT", element="barResource", targetPoint="TOPRIGHT" }
				},
				colorBinding="callingColor", 
			},
			{
				-- Generic Element Configuration HP bar background was resourceColor alpha .3
				id="frameColor2", type="Frame", parent="frameBackdrop", layer=15, alpha=0.6,
				attach = { 
					{ point="TOPLEFT", element="barHealth", targetPoint="BOTTOMLEFT", offsetX=1, offsetY=0 },
					{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT" }
				},
				colorBinding="resourceCOlor", 
			},
			{
				-- Generic Element Configuration 
				id="imgRole", type="ImageSet", parent="frame", layer=40,
				attach = {{ point="TOPLEFT", element="barHealth", targetPoint="TOPLEFT", offsetX=0, offsetY=0 }},
				-- Type Specific Element Configuration
				texAddon=AddonId, texFile="img/Roles12.png", nameBinding="role", cols=1, rows=5, 
				names = { ["tank"] = 0, ["heal"] = 1, ["dps"] = 2, ["support"] = 3 }, defaultIndex = "hide"
			},
			{
				-- Generic Element Configuration was nameMini 12
				id="labelName", type="Label", parent="frame", layer=40, alpha=1,
				attach = {{ point="CENTERLEFT", element="imgRole", targetPoint="CENTERRIGHT", offsetX=0, offsetY=0 }},
				visibilityBinding="name", 
				-- Type Specific Element Configuration
				text="{name}", default="", fontSize=12,
				color={r=1,g=1,b=1,a=1},
			},
			{
				-- Generic Element Configuration HPpercent text was fontsize 14 offsetx=2 Y=4
				id="labelHealth", type="Label", parent="frame", layer=40, alpha=1,
				attach = {{ point="CENTER", element="labelName", targetPoint="BOTTOMCENTER", offsetX=2, offsetY=4 }},
				visibilityBinding="healthtext", 
				-- Type Specific Element Configuration
				text="{healthPercent}%", default="", fontSize=14,
				color={r=1,g=1,b=1,a=1},
			},
			{
				-- Generic Element Configuration was TOPLEFT BOTTOMLEFT
				id="labelStatus", type="Label", parent="frame", layer=40, alpha=1,
				attach = {{ point="TOPLEFT", element="labelName", targetPoint="BOTTOMLEFT", offsetX=0, offsetY=-6 }},
				visibilityBinding="name",
				-- Type Specific Element Configuration
				text="{raidStatusMini}", default="", fontSize=14,
			},
			{
				-- Generic Element Configuration
				id="labelMark", type="Label", parent="frameBackdrop", layer=20,
				attach = {{ point="TOPRIGHT", element="frameBackdrop", targetPoint="TOPRIGHT", offsetX=1.5, offsetY=-3.5 }},
				visibilityBinding="mark",alpha=0.85,
				-- Type Specific Element Configuration
				text="{mark}", default="X", fontSize=22
			},
			{
				-- Generic Element Configuration
				id="imgReady", type="ImageSet", parent="frame", layer=60,
				attach = {{ point="CENTER", element="frame", targetPoint="CENTER" }},
				-- Type Specific Element Configuration
				texAddon=AddonId, texFile="img/wtReady.png", nameBinding="readyStatus", cols=1, rows=2, 
				names = { ["ready"] = 0, ["notready"] = 1 }, defaultIndex = "hide",
			},
			{
				--BorderColor was 1111white iconsize13 borderthickness1
				id="buffPanelDebuffs", type="BuffPanel", parent="frame", layer=80,
				attach = {{ point="BOTTOMRIGHT", element="frameBackdrop", targetPoint="BOTTOMRIGHT", offsetX=-1, offsetY=0 }},
				rows=1, cols=5, iconSize=14, iconSpacingHorizontal=1, iconSpacingVertical=1, borderThickness=.5, 
				acceptLowPriorityBuffs=false, acceptMediumPriorityBuffs=false, acceptHighPriorityBuffs=false, acceptCriticalPriorityBuffs=false,
				acceptLowPriorityDebuffs=true, acceptMediumPriorityDebuffs=true, acceptHighPriorityDebuffs=true, acceptCriticalPriorityDebuffs=true,
				growthDirection = "left_up", borderColor={r=0,g=0,b=0,a=1},
				sweepOverlay=false,
			},
			
		}
	}
	
	for idx,element in ipairs(template.elements) do
		if options.excludeBuffs and element.type=="BuffPanel" then
			-- Don't add buff panels if excluding them
		else
			self:CreateElement(element)
		end 
	end
	
	self:SetSecureMode("restricted")
	self:SetMouseoverUnit(self.UnitSpec)
	self:SetMouseMasking("limited")
	if options.clickToTarget then
		self.Event.LeftClick = "target @" .. self.UnitSpec
	end
	if options.contextMenu then
		self.Event.RightClick = function() if self.UnitId then Command.Unit.Menu(self.UnitId) end end
	end
end